/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.xml.registry;

import net.lucubrators.honeycomb.core.Comb;
import net.lucubrators.honeycomb.xml.registry.exceptions.CombNotFoundException;
import net.lucubrators.honeycomb.xml.registry.exceptions.DuplicateCombException;

/**
 * a registry for all known combs
 * 
 * @author gnalFF
 * 
 */
public interface CombRegistry {

	/**
	 * Checks if the registry contains a comb with the given id
	 * 
	 * @param id
	 *            the id to look for
	 * @return true if a comb is registed under the given id
	 */
	boolean contains(String id);

	/**
	 * Returns a comb which was registered with the given id
	 * 
	 * @param id
	 *            the id to which a controller was mapped
	 * @return a comb mapped to the given id. never null
	 * @throws CombNotFoundException
	 *             if there was no comb mapped to the given id
	 */
	Comb getById(String id) throws CombNotFoundException;

	/**
	 * Adds a comb to the registry
	 * 
	 * @param comb
	 *            the comb to be added
	 * @throws DuplicateCombException
	 *             if a comb was already registered with this id
	 */
	void register(Comb comb) throws DuplicateCombException;

	/**
	 * @return the number of combs registered in this registry
	 */
	int size();
}
