/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.xml.registry;

import java.util.HashMap;

import net.lucubrators.honeycomb.core.Comb;
import net.lucubrators.honeycomb.xml.registry.exceptions.CombNotFoundException;
import net.lucubrators.honeycomb.xml.registry.exceptions.DuplicateCombException;

/**
 * A default implementation of a {@link CombRegistry}
 * 
 * @author gnalFF
 * 
 */
public class DefaultCombRegistry implements CombRegistry {

	private final HashMap<String, Comb>	registry;

	public DefaultCombRegistry() {
		registry = new HashMap<String, Comb>();
	}

	@Override
	public Comb getById(final String id) {
		if (contains(id)) {
			return registry.get(id);
		}
		throw new CombNotFoundException("Could not find comb with id " + id);
	}

	@Override
	public boolean contains(final String id) {
		return registry.containsKey(id);
	}

	@Override
	public void register(final Comb comb) {
		if (contains(comb.getId())) {
			throw new DuplicateCombException("Comb is already present. Id: " + comb.getId());
		}
		registry.put(comb.getId(), comb);
	}

	@Override
	public int size() {
		return registry.size();
	}

}
